/* ------------------------------------------------------------------------- */
// eslint configuration for this file
//
/* global imports */

/* exported OverviewButton */


/* ------------------------------------------------------------------------- */
// enforce strict mode
"use strict";


/* ------------------------------------------------------------------------- */
// system libraries imports
const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const St = imports.gi.St;

/* ------------------------------------------------------------------------- */
// gnome shell imports
const Main = imports.ui.main;
const ExtensionUtils = imports.misc.extensionUtils;


/* ------------------------------------------------------------------------- */
// extension imports
const Extension = ExtensionUtils.getCurrentExtension();
const Utils = Extension.imports.lib.utils;


/* ------------------------------------------------------------------------- */
var OverviewButton = class OverviewButton {

  constructor() {

    // logger
    this._logger = new Utils.Logger(
      "overviewButton.js::OverviewButton"
    );

    this._icon = null;

    this._activities = Main.panel.statusArea.activities;
    // activities actor

    let gnomeVersion = imports.misc.config.PACKAGE_VERSION.split(".");
    if (gnomeVersion[0] >= 3 && gnomeVersion[1] >= 34) {
      this._activitiesActor = this._activities;
    }
    else {
      this._activitiesActor = Main.panel.statusArea.activities.actor;
    }
  }

  /* ....................................................................... */
  enable() {

    if (this._activities != null) {

      // compose icon file path
      let iconPath = GLib.build_filenamev([
        Extension.dir.get_path(),
        "icons",
        "overview-button.svg",
      ]);

      // create new gicon
      let gicon = Gio.icon_new_for_string(iconPath);

      // create overview button St.Icon
      this._icon = new St.Icon({
        gicon: gicon,
        style_class: "system-status-icon",
      });

      // remove label child
      this._activitiesActor.remove_child(this._activities._label);
      // add icon child
      this._activitiesActor.add_actor(this._icon);

    }
  }


  /* ....................................................................... */
  disable() {

    if (this._activities != null) {
      // remove icon child
      this._activitiesActor.remove_actor(this._icon);
      // add label child
      this._activitiesActor.add_child(this._activities._label);
    }

  }

};
